/*
 *  Project: Replica exchange Monte Carlo for Protein Folding in the HP model
 *  File:    Const.h
 *
 *  Note: The latest source code and information regarding this project 
 *  is available at http://www.cs.ubc.ca/labs/beta/Projects/REMC-HPPFP/
 *
 *  For citation purposes, please use:
 *  Thachuk C, Shmygelska A and Hoos H: Replica exchange Monte Carlo for 
 *  protein folding in the HP model. BMC Bioinformatics 2007, Submitted.
 * 
 *  Copyright (C) 2007  Chris Thachuk, Alena Shmygelska and Holger H Hoos
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */


#ifndef CONST_H
#define CONST_H


// #define TRACE_SQT_GENERAL_CACHED		// general sqt trace, held in memory until completion
#define TRACE_SQT_GENERAL_IMMEDIATE		// general sqt trace, dumped to file on the fly (doesn't work if more than 1 run)
// #define TRACE_SEED_FILE					// dump the seeds to a seeds file to reproduce results later
// #define TRACE_MST		// Minimum solution quality trace
// #define TRACE_SQT_DETAIL // detailed sqt trace for each replica
#define TRACE_ARI_MOVES // Accept, Reject, Impossible moves
#define TRACE_VERBOSE	// Verbose output messages 
// #define TRACE_REP_SWAPS		// Trace replica swap acceptance percentage
//#define ANNEALING
//#define RESEEDING

#define LOCAL		1
#define PULLMOVES   2
#define MIXED		3

#ifndef DIM
	#define DIM		2
#endif

#ifndef MOVESET
	#define MOVESET	LOCAL
#endif

#if DIM == 3
	#define L			256 
	#define LL			65536     
	#define HashSize	16777216
//	#define L			128
//	#define LL			16384
//	#define HashSize	2097152
	#define MinBoundary LL
	#define MaxBoundary HashSize - LL     
	#define I0			(L/2*LL + L/2*L + L/2)

#elif DIM == 2
//	#define L			1024 
//	#define LL			4096       
//	#define HashSize	1048576
	#define L			2048 
	#define LL			4096       
	#define HashSize	4194304
	
	#define MinBoundary LL
	#define MaxBoundary HashSize - LL     
	#define I0			(L/2*L + L/2)

//	#define L			64
//	#define HashSize	4096
//	#define I0			2028

#endif

#if defined LOWMEM
	#define L		128
	#define LL		512
	#define HashSize 	16384
	#define MinBoundary 	LL
	#define MaxBoundary	HashSize - LL
	#define I0		(L/2*L + L/2)
	#MAX_NUM		128

#endif

static const double K_b = 0.0019872;
static const double K_b2 = 0.0001679010;
//static const int MAX_SEQ_LENGTH = 512;
static const int MAX_SEQ_LENGTH = 1024;
static const int MAX_NUM_REPLICAS = 400;			// used to dimension the deltaValues array in REMSimulation
static const int MAX_NUM_ENERGY_VALUES = 1000;	// used to dimenstion the deltaValues array in REMSimulation

#define straight		1
#define right			2
#define left 			4
#define up				8
#define down			16
#define ground			32
#define LPempty			-1

#define H 				1
#define P 				-2

#endif 
