/*
 *  Project: Replica exchange Monte Carlo for Protein Folding in the HP model
 *  File:    REMSimulation.h
 *
 *  Note: The latest source code and information regarding this project 
 *  is available at http://www.cs.ubc.ca/labs/beta/Projects/REMC-HPPFP/
 *
 *  For citation purposes, please use:
 *  Thachuk C, Shmygelska A and Hoos H: Replica exchange Monte Carlo for 
 *  protein folding in the HP model. BMC Bioinformatics 2007, Submitted.
 * 
 *  Copyright (C) 2007  Chris Thachuk, Alena Shmygelska and Holger H Hoos
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

 
#ifndef REMSIMULATION_H
#define REMSIMULATION_H

#include <iostream>
#include <iomanip>
#include <algorithm>
#include <vector>
#include <string>
#include <map>
#include <fstream>
#include <sstream>
#include <math.h>
#include "Conformation.h"
#include "Const.h"
#include "Random.h"
#include "SearchParameters.h"
#include "stopwatch.h"

using namespace std;

typedef Conformation Replica;
typedef vector< Replica * > Replicas;
typedef vector< Replica * >::iterator ReplicaIterator;

class REMSimulation {
	private:
		Replicas replicas;			// vector of conformations
		int numReplicas;			// number of replicas in simulation
		SearchParameters params;	// search parameters for simulation
		double probDeltaValues[MAX_NUM_REPLICAS][MAX_NUM_ENERGY_VALUES]; // pre-computed probilities of delta values
		double tempValues[MAX_NUM_ENERGY_VALUES];			// the temperature values

#if defined TRACE_REP_SWAPS || defined TRACE_ARI_MOVES
		map<double,int> tempMap;
#endif
		// swaps the conformation references in the replicas vector
		// and swaps the temperatures of the two conformations
		void swapReplicas( int i, int j );
		
		// determines if the two replicas should be swapped based on
		// the metropolis criterian
		bool shouldSwapReplicas( int i, int j );
	
	public:
		// public constructor which requires the search parameters be
		// passed in for initialization
		REMSimulation( const SearchParameters& );
		~REMSimulation();

		// begins the REM simulation
		void runSimulation(vector<SQT_item>&);
};

#endif
