/*
 *  Project: Replica exchange Monte Carlo for Protein Folding in the HP model
 *  File:    SearchParameters.cpp
 *
 *  Note: The latest source code and information regarding this project 
 *  is available at http://www.cs.ubc.ca/labs/beta/Projects/REMC-HPPFP/
 *
 *  For citation purposes, please use:
 *  Thachuk C, Shmygelska A and Hoos H: Replica exchange Monte Carlo for 
 *  protein folding in the HP model. BMC Bioinformatics 2007, Submitted.
 * 
 *  Copyright (C) 2007  Chris Thachuk, Alena Shmygelska and Holger H Hoos
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */


#include "SearchParameters.h"

// must define the static memebers with a default initialization value;
int SearchParameters::numReplicas = 10;
int SearchParameters::numLocalSteps = 25;
int SearchParameters::knownEnergy = 0;
int SearchParameters::numRuns = 1;

long SearchParameters::suppliedSeed = 0;

double SearchParameters::minTemperature = 1.0;
double SearchParameters::maxTemperature = 225.0;
vector<double> SearchParameters::temperatureValues;
double SearchParameters::maxRunTime = 36000;
double SearchParameters::mu = 1.0;
double SearchParameters::reseedAfter = 1000;
double SearchParameters::reseedTimeout = 3.0;
double SearchParameters::pmWeight = 0.4;
	
string SearchParameters::sequence = "hphphphphphphphphphphphphphphphphphp";
string SearchParameters::experimentID = "default_experiment";
string SearchParameters::traceFile = "traceFile.txt";
string SearchParameters::initConf = "";

bool SearchParameters::showHydrogenBonds = false;


