/*
 *  Project: Replica exchange Monte Carlo for Protein Folding in the HP model
 *  File:    SearchParameters.h
 *
 *  Note: The latest source code and information regarding this project 
 *  is available at http://www.cs.ubc.ca/labs/beta/Projects/REMC-HPPFP/
 *
 *  For citation purposes, please use:
 *  Thachuk C, Shmygelska A and Hoos H: Replica exchange Monte Carlo for 
 *  protein folding in the HP model. BMC Bioinformatics 2007, Submitted.
 * 
 *  Copyright (C) 2007  Chris Thachuk, Alena Shmygelska and Holger H Hoos
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */


 
#ifndef SEARCHPARAMETERS_H
#define SEARCHPARAMETERS_H

#include <string>
#include <vector>
#include "Const.h"

using namespace std;

class SearchParameters {
	public:
		static int numRuns;
		static int numReplicas;
		static int numLocalSteps;
		//static int numExchanges;
		static int knownEnergy;
		
		static long suppliedSeed;
		
		static double minTemperature;
		static double maxTemperature;
		static vector<double> temperatureValues;
		static double maxRunTime;
		static double mu;
		static double reseedAfter;
		static double reseedTimeout;
		static double pmWeight;
		
		static string sequence;
		static string experimentID;
		static string traceFile;
		static string initConf;
		
		static bool showHydrogenBonds;
};

#endif
