/*
 *  Project: Replica exchange Monte Carlo for Protein Folding in the HP model
 *  File:    SearchResult.h
 *
 *  Note: The latest source code and information regarding this project 
 *  is available at http://www.cs.ubc.ca/labs/beta/Projects/REMC-HPPFP/
 *
 *  For citation purposes, please use:
 *  Thachuk C, Shmygelska A and Hoos H: Replica exchange Monte Carlo for 
 *  protein folding in the HP model. BMC Bioinformatics 2007, Submitted.
 * 
 *  Copyright (C) 2007  Chris Thachuk, Alena Shmygelska and Holger H Hoos
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */


#ifndef SEARCH_RESULT_H
#define SEARCH_RESULT_H

#include <string>
#include <fstream>
#include <sstream>
#include <vector>
#include <iostream>
#include "Const.h"

using namespace std;

struct SQT_item {
	long double runLength;
	float runTime;
	int freeEnergy;
	double T;
	string relDirections;
};

class SearchResult {

	SQT_item ms_sqt;		 // solution qualitity trace statistics of "minimum" solution
	string experimentID;
	int replicaID;
	long double movesAccepted;
	long double movesRejected;
	long double movesImpossible;
	long double numSteps;
	long double numResidues;

#ifdef TRACE_SQT_DETAIL
	ofstream sqt;	 // solution quatily trace (ie. trace events when new minimum found)
#endif
#ifdef TRACE_MST
	vector< SQT_item > ms_trace; // trace of "new" best solutions as they occur
#endif
	
	public:
		SearchResult(const string &experimentID, const int replicaID);
		void writeResults();
		void addSQT_item( const long double run_length, const float run_time, const int free_energy, 
			const double T, const int relDirections[], const int dirLength );
		SQT_item& getMinimumSolution();
		void setExperimentID(const string &experimentID);
		void setReplicaID(const int replicaID);
		string& getExperimentID();
		int getReplicaID();
		void setAcceptedMoves(long double);
		void setRejectedMoves(long double);
		void setImpossibleMoves(long double);
		void setNumSteps(long double);
		void setNumResidues(long double);
		void resetMinimumSolution();
		void setMinimumSolution(const int [], const int, const int);
		
		long double getAcceptedMoves();
		long double getRejectedMoves();
		long double getImpossibleMoves();
		long double getNumSteps();
		long double getNumResidues();
		
		
		
#ifdef TRACE_SQT_DETAIL
		vector< SQT_item > getSQT();
#endif
#ifdef TRACE_MST
		string getMSTrace();
#endif
};

#endif
