/*
 *  Project: Replica exchange Monte Carlo for Protein Folding in the HP model
 *  File:    Timer.cpp
 *
 *  Note: The latest source code and information regarding this project 
 *  is available at http://www.cs.ubc.ca/labs/beta/Projects/REMC-HPPFP/
 *
 *  For citation purposes, please use:
 *  Thachuk C, Shmygelska A and Hoos H: Replica exchange Monte Carlo for 
 *  protein folding in the HP model. BMC Bioinformatics 2007, Submitted.
 * 
 *  Copyright (C) 2007  Chris Thachuk, Alena Shmygelska and Holger H Hoos
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#include "Timer.h"

// Timer class for measuring cpu-time of program fragments */

Timer::Timer(void) {
  t_start_u=0;
  t_start_s=0;
  t_stop_u=0;
  t_stop_s=0;
  st = STOPPED;
  }

void Timer::start(void) {
  struct tms buf;
  clock_t t;
  t = times(&buf);
  t_start_u = buf.tms_utime;
  t_start_s = buf.tms_stime;
  st = RUNNING;
  }

void Timer::stop(void) {
  struct tms buf;
  clock_t t;
  t = times(&buf);
  t_stop_u = buf.tms_utime;
  t_stop_s = buf.tms_stime;  
  st = STOPPED;
  }

void Timer::reset(void) {
  struct tms buf;
  clock_t t;
  t = times(&buf);
  t_start_u = buf.tms_utime;
  t_start_s = buf.tms_stime;
  }

float Timer::elapsed(void) {
  struct tms buf;
  if (st==STOPPED)
    return(1.0*((t_stop_u+t_stop_s)-(t_start_u+t_start_s))/CLOCKS_PER_SEC);
  else {
    clock_t t;
    t = times(&buf);
	//cout << "user time: " << (1.0*((buf.tms_utime)-(t_start_u))/CLK_TCK) << endl;
	//cout << "sys  time: " << (1.0*((buf.tms_stime)-(t_start_s))/CLK_TCK) << endl;
	//cout << "wall time: " << (1.0*((buf.tms_utime+buf.tms_stime)-(t_start_u+t_start_s))/CLK_TCK) << endl << endl;
    return(1.0*((buf.tms_utime+buf.tms_stime)-(t_start_u+t_start_s))/CLOCKS_PER_SEC);
    }
  }

float Timer::elapsedDetail(void) {
  struct tms buf;
  if (st==STOPPED)
    return(1.0*((t_stop_u+t_stop_s)-(t_start_u+t_start_s))/CLOCKS_PER_SEC);
  else {
    clock_t t;
    t = times(&buf);
	cout << "user time: " << (1.0*((buf.tms_utime)-(t_start_u))/CLOCKS_PER_SEC) << endl;
	cout << "sys  time: " << (1.0*((buf.tms_stime)-(t_start_s))/CLOCKS_PER_SEC) << endl;
	cout << "real time: " << (1.0*((buf.tms_utime+buf.tms_stime)-(t_start_u+t_start_s))/CLOCKS_PER_SEC) << endl << endl;
    return(1.0*((buf.tms_utime+buf.tms_stime)-(t_start_u+t_start_s))/CLOCKS_PER_SEC);
    }
  }



float Timer::resolution(void) {
  return(1.0/CLOCKS_PER_SEC);
  }


