/*
 *  Project: Replica exchange Monte Carlo for Protein Folding in the HP model
 *  File:    Timer.h
 *
 *  Note: The latest source code and information regarding this project 
 *  is available at http://www.cs.ubc.ca/labs/beta/Projects/REMC-HPPFP/
 *
 *  For citation purposes, please use:
 *  Thachuk C, Shmygelska A and Hoos H: Replica exchange Monte Carlo for 
 *  protein folding in the HP model. BMC Bioinformatics 2007, Submitted.
 * 
 *  Copyright (C) 2007  Chris Thachuk, Alena Shmygelska and Holger H Hoos
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#ifndef TIMER_H
#define TIMER_H
#include <sys/times.h>
#include <sys/param.h>
#include <limits.h>
#include <iostream>
#include "Const.h"
#include <time.h>
#include <unistd.h>
#include <math.h>

using namespace std;

// Timer class for measuring cpu-time of program fragments */
class Timer {
  clock_t t_start_u, t_start_s;
  clock_t t_stop_u, t_stop_s;
  enum state {RUNNING,STOPPED};
  state st;
  
public:
  Timer(void);
  void start(void);
  void stop(void);
  void reset(void);
  float resolution(void); 
  // returns resolution of Timer in CPU-seconds */
  float elapsed(void);  // returns stopped time in CPU-seconds */
  float elapsedDetail(void);
};

#ifndef HZ
#define HZ 60
#endif
#endif
